==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/opensearch/kotlin/inputs/DomainAdvancedSecurityOptionsMasterUserOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.opensearch.kotlin.inputs

import com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsMasterUserOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property masterUserArn ARN for the main user. Only specify if `internal_user_database_enabled` is not set or set to `false`.
 * @property masterUserName Main user's username, which is stored in the Amazon OpenSearch Service domain's internal database. Only specify if `internal_user_database_enabled` is set to `true`.
 * @property masterUserPassword Main user's password, which is stored in the Amazon OpenSearch Service domain's internal database. Only specify if `internal_user_database_enabled` is set to `true`.
 */
public data class DomainAdvancedSecurityOptionsMasterUserOptionsArgs(
    public val masterUserArn: Output<String>? = null,
    public val masterUserName: Output<String>? = null,
    public val masterUserPassword: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsMasterUserOptionsArgs> {
    override fun toJava():
        com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsMasterUserOptionsArgs =
        com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsMasterUserOptionsArgs.builder()
            .masterUserArn(masterUserArn?.applyValue({ args0 -> args0 }))
            .masterUserName(masterUserName?.applyValue({ args0 -> args0 }))
            .masterUserPassword(masterUserPassword?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DomainAdvancedSecurityOptionsMasterUserOptionsArgs].
 */
@PulumiTagMarker
public class DomainAdvancedSecurityOptionsMasterUserOptionsArgsBuilder internal constructor() {
    private var masterUserArn: Output<String>? = null

    private var masterUserName: Output<String>? = null

    private var masterUserPassword: Output<String>? = null

    /**
     * @param value ARN for the main user. Only specify if `internal_user_database_enabled` is not set or set to `false`.
     */
    @JvmName("jgjxdfgrspjjcknw")
    public suspend fun masterUserArn(`value`: Output<String>) {
        this.masterUserArn = value
    }

    /**
     * @param value Main user's username, which is stored in the Amazon OpenSearch Service domain's internal database. Only specify if `internal_user_database_enabled` is set to `true`.
     */
    @JvmName("klimeukwmnywbinc")
    public suspend fun masterUserName(`value`: Output<String>) {
        this.masterUserName = value
    }

    /**
     * @param value Main user's password, which is stored in the Amazon OpenSearch Service domain's internal database. Only specify if `internal_user_database_enabled` is set to `true`.
     */
    @JvmName("bdgvvdoxbbfouycj")
    public suspend fun masterUserPassword(`value`: Output<String>) {
        this.masterUserPassword = value
    }

    /**
     * @param value ARN for the main user. Only specify if `internal_user_database_enabled` is not set or set to `false`.
     */
    @JvmName("rqktwvquktnvqasm")
    public suspend fun masterUserArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.masterUserArn = mapped
    }

    /**
     * @param value Main user's username, which is stored in the Amazon OpenSearch Service domain's internal database. Only specify if `internal_user_database_enabled` is set to `true`.
     */
    @JvmName("pkfxtbbixjdjdqjk")
    public suspend fun masterUserName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.masterUserName = mapped
    }

    /**
     * @param value Main user's password, which is stored in the Amazon OpenSearch Service domain's internal database. Only specify if `internal_user_database_enabled` is set to `true`.
     */
    @JvmName("rbpwrtxymyqwebvv")
    public suspend fun masterUserPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.masterUserPassword = mapped
    }

    internal fun build(): DomainAdvancedSecurityOptionsMasterUserOptionsArgs =
        DomainAdvancedSecurityOptionsMasterUserOptionsArgs(
            masterUserArn = masterUserArn,
            masterUserName = masterUserName,
            masterUserPassword = masterUserPassword,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/opensearch/kotlin/inputs/DomainAdvancedSecurityOptionsMasterUserOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.opensearch.kotlin.inputs

import com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsMasterUserOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property masterUserArn ARN for the main user. Only specify if `internal_user_database_enabled` is not set or set to `false`.
 * @property masterUserName Main user's username, which is stored in the Amazon OpenSearch Service domain's internal database. Only specify if `internal_user_database_enabled` is set to `true`.
 * @property masterUserPassword Main user's password, which is stored in the Amazon OpenSearch Service domain's internal database. Only specify if `internal_user_database_enabled` is set to `true`.
 */
public data class DomainAdvancedSecurityOptionsMasterUserOptionsArgs(
    public val masterUserArn: Output<String>? = null,
    public val masterUserName: Output<String>? = null,
    public val masterUserPassword: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsMasterUserOptionsArgs> {
    override fun toJava(): com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsMasterUserOptionsArgs =
        com.pulumi.aws.opensearch.inputs.DomainAdvancedSecurityOptionsMasterUserOptionsArgs.builder()
            .masterUserArn(masterUserArn?.applyValue({ args0 -> args0 }))
            .masterUserName(masterUserName?.applyValue({ args0 -> args0 }))
            .masterUserPassword(masterUserPassword?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DomainAdvancedSecurityOptionsMasterUserOptionsArgs].
 */
@PulumiTagMarker
public class DomainAdvancedSecurityOptionsMasterUserOptionsArgsBuilder internal constructor() {
    private var masterUserArn: Output<String>? = null

    private var masterUserName: Output<String>? = null

    private var masterUserPassword: Output<String>? = null

    /**
     * @param value ARN for the main user. Only specify if `internal_user_database_enabled` is not set or set to `false`.
     */
    @JvmName("dlvqibtdgmovimds")
    public suspend fun masterUserArn(`value`: Output<String>) {
        this.masterUserArn = value
    }

    /**
     * @param value Main user's username, which is stored in the Amazon OpenSearch Service domain's internal database. Only specify if `internal_user_database_enabled` is set to `true`.
     */
    @JvmName("tppxshqmuorwfmlm")
    public suspend fun masterUserName(`value`: Output<String>) {
        this.masterUserName = value
    }

    /**
     * @param value Main user's password, which is stored in the Amazon OpenSearch Service domain's internal database. Only specify if `internal_user_database_enabled` is set to `true`.
     */
    @JvmName("esjnskieqqgnpkfr")
    public suspend fun masterUserPassword(`value`: Output<String>) {
        this.masterUserPassword = value
    }

    /**
     * @param value ARN for the main user. Only specify if `internal_user_database_enabled` is not set or set to `false`.
     */
    @JvmName("ffdjwwcswnywnkvg")
    public suspend fun masterUserArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.masterUserArn = mapped
    }

    /**
     * @param value Main user's username, which is stored in the Amazon OpenSearch Service domain's internal database. Only specify if `internal_user_database_enabled` is set to `true`.
     */
    @JvmName("ncbyidixxbwsnwpy")
    public suspend fun masterUserName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.masterUserName = mapped
    }

    /**
     * @param value Main user's password, which is stored in the Amazon OpenSearch Service domain's internal database. Only specify if `internal_user_database_enabled` is set to `true`.
     */
    @JvmName("tmnwrtvdikvmwvsy")
    public suspend fun masterUserPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.masterUserPassword = mapped
    }

    internal fun build(): DomainAdvancedSecurityOptionsMasterUserOptionsArgs =
        DomainAdvancedSecurityOptionsMasterUserOptionsArgs(
            masterUserArn = masterUserArn,
            masterUserName = masterUserName,
            masterUserPassword = masterUserPassword,
        )
}
